/**
 * Main Application script
 */
import React, { Fragment, FunctionComponent, useCallback, useState } from 'react';
import { BryntumDemoHeader, BryntumThemeCombo, BryntumGantt, BryntumGanttProps } from '@bryntum/gantt-react';
// import { ganttConfig } from './AppConfig';
import './App.scss';
import { CycleResolutionPopup, Popup, ProjectModel } from '@bryntum/gantt';
import Chip from './Chip';

const App: FunctionComponent = () => {
    const clickHandler = useCallback((props:any)=> {
        let popup = new Popup({
            owner: props.source.parent?.parent?.parent,
            header: 'Sample Popup',
            autoShow: false,
            centered: true,
            closable: true,
            closeAction: 'destroy',
            width: '32em',
            minHeight: '400px',
            maxHeight: '400px',
            layout: 'vbox',
            items: [
                // {
                //     type: 'widget',
                //     html: <Chip onClick={() => {console.log('clicked')}} />,
                // },
            ]
        });
        popup.show();
    },[])

    const [ganttConfig] = useState<BryntumGanttProps>({
        project: {
            autoLoad: true,
            autoSync: true,
            transport: {
                load: {
                    url: 'data/launch-saas.json'
                },
                sync: {
                    url: 'test/api'
                }
            },
            // This config enables response validation and dumping of found errors to the browser console.
            // It's meant to be used as a development stage helper only so please set it to false for production systems.
            validateResponse : true,
            listeners : {
                cycle: ({
                    schedulingIssue,
                    continueWithResolutionResult,
                  }: {
                    schedulingIssue: any;
                    continueWithResolutionResult: any;
                  }) => {
                    const resolutions = schedulingIssue.getResolutions();
                    // use the second resolution of suggested for inActivation
                    resolutions[1].resolve();
                    continueWithResolutionResult('Resume');
                    schedulingIssue.collapse();
                  },
            }
        },
        columns: [{ type: 'name', field: 'name', width: 250 }],
        viewPreset: 'weekAndDayLetter',
        barMargin: 10,
        features : {
            percentBar: false
        },
        tbar: [
            {
                type: 'button',
                text: 'Show Popup',
                onAction: (props: any) => {
                    clickHandler(props)
                },
              },
        ]
    });
    return (
        <Fragment>
            <BryntumGantt {...ganttConfig} />
        </Fragment>
    );
};

export default App;
